Metadata

Struct Metadata 

pub struct Metadata { /* private fields */ }
Metadata information for an archive entry.

Implementations

Source

impl Metadata

pub fn from_fields( size: i64, nodetype: u32, perm: c_uint, mtime: i64, mtime_nano: i64, ) -> Self

Create metadata for in-memory entries without filesystem dependency.

pub fn filepath(&self) -> &str

Returns the filepath of the entry.

pub fn size(&self) -> i64

Returns the size of the entry in bytes.

pub fn nodetype(&self) -> u32

Returns the node type (file, directory, etc.)

pub fn perm(&self) -> c_uint

Returns the permissions mode.

pub fn ctime(&self) -> i64

Returns the creation time in seconds.

pub fn ctime_nano(&self) -> i64

Returns the creation time nanoseconds part.

pub fn atime(&self) -> i64

Returns the last access time in seconds.

pub fn atime_nano(&self) -> i64

Returns the last access time nanoseconds part.

pub fn mtime(&self) -> i64

Returns the last modification time in seconds.

pub fn mtime_nano(&self) -> i64

Returns the last modification time nanoseconds part.

pub fn owner(&self) -> uid_t

Returns the owner UID.

pub fn group(&self) -> gid_t

Returns the group GID.

pub fn is_dir(&self) -> bool

Returns true if the entry is a directory.

pub fn is_file(&self) -> bool

Returns true if the entry is a regular file.

Returns true if the entry is a symbolic link.

pub fn is_block_device(&self) -> bool

Returns true if the entry is a block device.

pub fn is_char_device(&self) -> bool

Returns true if the entry is a character device.

pub fn is_fifo(&self) -> bool

Returns true if the entry is a FIFO (named pipe).

pub fn is_socket(&self) -> bool

Returns true if the entry is a socket.