pub struct Metadata { /* private fields */ }Expand description
Metadata information for an archive entry.
Implementations
Sourceimpl Metadata
impl Metadata
Sourcepub fn from_fields(
size: i64,
nodetype: u32,
perm: c_uint,
mtime: i64,
mtime_nano: i64,
) -> Self
pub fn from_fields( size: i64, nodetype: u32, perm: c_uint, mtime: i64, mtime_nano: i64, ) -> Self
Create metadata for in-memory entries without filesystem dependency.
Sourcepub fn ctime_nano(&self) -> i64
pub fn ctime_nano(&self) -> i64
Returns the creation time nanoseconds part.
Sourcepub fn atime_nano(&self) -> i64
pub fn atime_nano(&self) -> i64
Returns the last access time nanoseconds part.
Sourcepub fn mtime_nano(&self) -> i64
pub fn mtime_nano(&self) -> i64
Returns the last modification time nanoseconds part.
Sourcepub fn is_symlink(&self) -> bool
pub fn is_symlink(&self) -> bool
Returns true if the entry is a symbolic link.
Sourcepub fn is_block_device(&self) -> bool
pub fn is_block_device(&self) -> bool
Returns true if the entry is a block device.
Sourcepub fn is_char_device(&self) -> bool
pub fn is_char_device(&self) -> bool
Returns true if the entry is a character device.